import React, { useEffect, useState } from "react";
import { Button, Text } from "react-native-paper";
import analytics from "../utils/segment";
import { SEGMENT_EVENTS } from "../data/segmentEvents";
import { useLMS } from "../context/context";
import { IBusiness } from "../typings/business";
import { View, ViewStyle } from "react-native";
import { showMessage } from "react-native-flash-message";

type SummaryCardProps = {
  onClick?(): void;
};

export const SummaryCard: React.ComponentType<SummaryCardProps> = ({
  onClick,
}) => {
  const [detail, setDetail] = useState<IBusiness | undefined>(undefined);
  const { info, userDetail } = useLMS();

  useEffect(() => {
    if (!info) {
      showMessage({ message: "Email is required", type: "danger" });
    } else {
      setDetail(userDetail);
    }
  }, [info, userDetail]);

  return (
    <View style={styles.header as ViewStyle}>
      <View style={styles.itemWrapper}>
        <View style={styles.items}>
          <Text variant={"bodySmall"}>Active Loans</Text>
          <Text variant={"bodyLarge"}>0</Text>
        </View>
        <View style={styles.column}>
          <Text variant={"bodySmall"}>Applications</Text>
          <Text variant={"bodyLarge"}>0</Text>
        </View>
        <View style={styles.items}>
          <Text variant={"bodySmall"}>Amount Due</Text>
          <Text variant={"bodyLarge"}>
            PKR{" "}
            {`${(
              (detail?.kyb.credit_limit || 0) -
              (detail?.kyb.available_credit_limit || 0)
            ).toLocaleString()}`}
          </Text>
        </View>
      </View>
      <View style={styles.gap} />
      <View style={{ ...styles.column, alignItems: "center" }}>
        <Button
          mode={"contained"}
          onPress={() => {
            onClick?.();
            analytics.track(SEGMENT_EVENTS.START_FINANCE_APPLICATION);
          }}
        >
          Apply for Financing
        </Button>
        <View style={styles.gap} />
        <Text variant={"bodyMedium"}>
          Credit Limit Left: PKR{" "}
          {(detail?.kyb.available_credit_limit || 0).toLocaleString()}
        </Text>
      </View>
    </View>
  );
};

const styles = {
  header: {
    width: "100%",
    borderRadius: 4,
    borderWidth: 1,
    borderColor: "#E5EAF2",
    paddingTop: 16,
    paddingBottom: 16,
    justifyContent: "space-between",
    alignItems: "center",
  },

  row: {
    display: "flex",
    flexDirection: "row",
  } as ViewStyle,

  column: {
    display: "flex",
    flexDirection: "column",
  } as ViewStyle,

  itemWrapper: {
    display: "flex",
    flexDirection: "row",
    justifyContent: "space-between",
    width: "100%",
    paddingLeft: 16,
    paddingRight: 16,
  } as ViewStyle,

  gap: {
    width: 10,
    height: 10,
  },

  items: {
    display: "flex",
    flexDirection: "column",
    alignItems: "flex-start",
  } as ViewStyle,
};
